SystemOrganization addCategory: #'Coral-Tests'!

PPAbstractParserTest subclass: #CLICommandTest
	instanceVariableNames: 'h m s command environment'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Coral-Tests'!

!CLICommandTest methodsFor: 'running' stamp: 'DamienPollet 8/16/2011 17:45'!
setUp
	"example taken from http://rubydoc.info/gems/cri/2.0.2/file/README.md"
	environment := CLIAdhocEnvironment in: nil out: String new writeStream err: String new writeStream.
	
	command := (CLICommandParser named: 'dostuff')
		aliases: #('ds' 'stuff');
		summary: 'does stuff';
		description: 'This command does a lot of stuff. I really mean a lot.'.
		
	h := command option -'h' --'help';
		description: 'show help for this command';
		do: [ :cmd |
			cmd err << cmd help.
			cmd exitSuccess ].
	
	m := command option -'m' --'more';
		description: 'do even more stuff'.

	s := command option -'s' --'stuff'; any;
		 description: 'specify stuff to do'.
	
	command do: [ :cmd | |stuff|
		stuff := cmd atOptionNamed: #stuff ifNone: [ 'generic stuff' ].
		cmd << 'Doing ' << stuff << '!!'; cr.
		(cmd hasOptionNamed: #more)
			ifTrue: [ cmd << 'Doing it even more!!'; cr ]
	]! !

!CLICommandTest methodsFor: 'tests-parsing' stamp: 'DamienPollet 8/11/2011 01:53'!
testAlone
	| cmd |
	cmd := self assert: command parse: #('dostuff').
	self assert: cmd options isEmpty.
	self assert: cmd parameters isEmpty.
	self assert: cmd subcommand isNil! !

!CLICommandTest methodsFor: 'tests-parsing' stamp: 'DamienPollet 8/11/2011 01:56'!
testHelp
	| cmd |
	cmd := self assert: command parse: #('dostuff' '-h').
	self assert: (cmd hasOptionNamed: #help).
	
	cmd := self assert: command parse: #('dostuff' '--help').
	self assert: (cmd hasOptionNamed: #help).

	self assert: command fail:  #('dostuff' '-help').
	self assert: command fail:  #('dostuff' '--h').
! !

!CLICommandTest methodsFor: 'tests-parsing' stamp: 'DamienPollet 8/11/2011 01:57'!
testMore
	| cmd |
	cmd := self assert: command parse: #('dostuff' '-m').
	self assert: (cmd hasOptionNamed: #more).

	cmd := self assert: command parse: #('dostuff' '--more').
	self assert: (cmd hasOptionNamed: #more).

	self assert: command fail:  #('dostuff' '-more').
	self assert: command fail:  #('dostuff' '--m').
! !

!CLICommandTest methodsFor: 'tests-parsing' stamp: 'DamienPollet 8/11/2011 01:58'!
testMoreStuff
	| cmd |
	cmd := self assert: command parse: #('dostuff' '-m' '-s' 'foo').
	self assert: (cmd hasOptionNamed: #more).
	self assert: 'foo' equals: (cmd atOptionNamed: #stuff).

	cmd := self assert: command parse: #('dostuff' '-m' '--stuff' 'foo').
	self assert: (cmd hasOptionNamed: #more).
	self assert: 'foo' equals: (cmd atOptionNamed: #stuff).

	self assert: command fail:  #('dostuff' '-m' '-stuff' 'foo').
	self assert: command fail:  #('dostuff' '-m' '--s' 'foo').
	self assert: command fail: #('dostuff' '-more' '-s' 'foo').
	self assert: command fail: #('dostuff' '--m' '--stuff' 'foo').

	self assert: command fail: #('dostuff' '-m' '-s').
	self assert: command fail: #('dostuff' '-m' '--stuff').
	self assert: command fail: #('dostuff' '-m' '-s' 'foo' 'bar').
	self assert: command fail: #('dostuff' '-m' '--stuff' 'foo' 'bar').
! !

!CLICommandTest methodsFor: 'tests-running' stamp: 'DamienPollet 8/11/2011 01:29'!
testRun
	command runOn: #('dostuff') in: environment.
	self assert: environment err isEmpty.
	self assert: environment out contents = 'Doing generic stuff!!
'! !

!CLICommandTest methodsFor: 'tests-todo' stamp: 'DamienPollet 8/11/2011 04:10'!
testRunHelp
	command runOn: #('dostuff' '--help' '--more') in: environment.
	self deny: environment err isEmpty.
	self assert: environment out isEmpty "it should have exited just after displaying the help"! !

!CLICommandTest methodsFor: 'tests-running' stamp: 'DamienPollet 8/11/2011 01:34'!
testRunMore
	command runOn: #('dostuff' '--more') in: environment.
	self assert: environment err isEmpty.
	self
		assert: 'Doing generic stuff!!
Doing it even more!!
'
		equals: environment out contents! !

!CLICommandTest methodsFor: 'tests-running' stamp: 'DamienPollet 8/11/2011 03:24'!
testRunStuff
	command runOn: #('dostuff' '--stuff' 'stuff just for you') in: environment.
	self assert: environment err isEmpty.
	self
		assert: 'Doing stuff just for you!!
'
		equals: environment out contents! !

!CLICommandTest methodsFor: 'tests-parsing' stamp: 'DamienPollet 8/10/2011 17:22'!
testStuff
	self assert: command parse: #('dostuff' '-s' 'foo').
	self assert: command parse: #('dostuff' '--stuff' 'foo').
	self assert: command fail:  #('dostuff' '-stuff' 'foo').
	self assert: command fail:  #('dostuff' '--s' 'foo').

	self assert: command fail: #('dostuff' '-s').
	self assert: command fail: #('dostuff' '--stuff').
	self assert: command fail: #('dostuff' '-s' 'foo' 'bar').
	self assert: command fail: #('dostuff' '--stuff' 'foo' 'bar').
! !

PPAbstractParserTest subclass: #CLIParsingTest
	instanceVariableNames: 'any anyOf command optionBoth optionLong optionShort subcommand anyPlus anyStar'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Coral-Tests'!

!CLIParsingTest class methodsFor: 'accessing' stamp: 'DamienPollet 8/7/2011 13:26'!
packageNamesUnderTest
	^ #('Coral')! !

!CLIParsingTest methodsFor: 'fixtures' stamp: 'DamienPollet 8/10/2011 18:42'!
any
	^ CLIParameterParser any name: 'something'! !

!CLIParsingTest methodsFor: 'fixtures' stamp: 'DamienPollet 8/10/2011 18:42'!
anyOf
	^ (CLIParameterParser anyOf: #(left right up down))
		name: 'direction'! !

!CLIParsingTest methodsFor: 'fixtures' stamp: 'DamienPollet 8/10/2011 18:34'!
command
	^ (CLICommandParser named: 'foo')
		aliases: #('fu' 'f');
		options: {
			self optionBoth parameter: self anyOf.
			self optionLong.
			self optionShort };
		parameters: { self any }! !

!CLIParsingTest methodsFor: 'fixtures' stamp: 'DamienPollet 8/10/2011 18:34'!
optionBoth
	^ CLIOptionParser new
		short: $b;
		long: 'both'! !

!CLIParsingTest methodsFor: 'fixtures' stamp: 'DamienPollet 8/10/2011 18:34'!
optionLong
	^ CLIOptionParser new
		long: 'long'! !

!CLIParsingTest methodsFor: 'fixtures' stamp: 'DamienPollet 8/10/2011 18:34'!
optionShort
	^ CLIOptionParser new
		short: $s! !

!CLIParsingTest methodsFor: 'running' stamp: 'DamienPollet 8/10/2011 20:18'!
setUp
	super setUp.
	
	any := self any.
	anyPlus := self any plus.
	anyStar := self any star.
	
	anyOf := self anyOf.
	command := self command.
	optionBoth := self optionBoth.
	optionLong := self optionLong.
	optionShort := self optionShort.
	subcommand := self subcommand! !

!CLIParsingTest methodsFor: 'fixtures' stamp: 'DamienPollet 8/10/2011 18:34'!
subcommand
	^ (CLICommandParser named: 'bar')
		subcommands: { self command }! !

!CLIParsingTest methodsFor: 'tests-parameters' stamp: 'DamienPollet 8/10/2011 20:19'!
testAny
	self assert: any parse: #('abc') to: 'abc'.
	self assert: any parse: #('123') to: '123'.
	self assert: any parse: #('x & ;') to: 'x & ;'.
	self assert: any parse: #('') to: ''.
	
	self assert: any parse: #('123' 'abc') end: 1.
	
	self assert: any fail: #().
! !

!CLIParsingTest methodsFor: 'tests-fixme' stamp: 'DamienPollet 8/10/2011 20:06'!
testAnyDashes
	<expectedFailure>
	"There is an ambiguity: should we accept an argument even if it looks like an option flag?"
	self assert: any fail: #('-x').
	self assert: any fail: #('--foo').
	
	self assert: anyPlus parse: #('foo' '-x') to: #('foo') end: 1.
	
	self assert: anyStar fail: #('--foo' '-x') end: 0.
	self assert: anyStar parse: #('--foo' '-x') to: #() end: 0.! !

!CLIParsingTest methodsFor: 'tests-parameters' stamp: 'DamienPollet 8/10/2011 19:56'!
testAnyOf
	self assert: anyOf parse: #('left') to: 'left'.
	self assert: anyOf parse: #('up') to: 'up'.
	
	self assert: anyOf parse: #('down' 'right') to: 'down' end: 1.
	
	self assert: anyOf fail: #('upper').
	self assert: anyOf fail: #('leftmost').
	self assert: anyOf fail: #('incorrect')
! !

!CLIParsingTest methodsFor: 'tests-parameters' stamp: 'DamienPollet 8/10/2011 19:58'!
testAnyOfPlus
	| p |
	p := anyOf plus.
	self assert: p parse: #('down' 'right' 'incorrect' 'left') to: #('down' 'right') end: 2.
! !

!CLIParsingTest methodsFor: 'tests-parameters' stamp: 'DamienPollet 8/10/2011 19:57'!
testAnyOptional
	| p |
	p := any optional.
	self assert: p parse: #('abc') to: 'abc'.
	self assert: p parse: #('123') to: '123'.
	self assert: p parse: #('x & ;') to: 'x & ;'.
	self assert: p parse: #('') to: ''.
	
	self assert: p parse: #('123' 'abc') end: 1.
	
	self assert: p parse: #() to: nil.
! !

!CLIParsingTest methodsFor: 'tests-parameters' stamp: 'DamienPollet 8/10/2011 20:01'!
testAnyPlus

	self assert: anyPlus parse: #('abc') to: #('abc').
	self assert: anyPlus parse: #('123') to: #('123').
	self assert: anyPlus parse: #('x & ;') to: #('x & ;').
	self assert: anyPlus parse: #('') to: #('').
	
	self assert: anyPlus parse: #('123' 'abc' 'jk6') to: #('123' 'abc' 'jk6').
	
	self assert: anyPlus fail: #().
! !

!CLIParsingTest methodsFor: 'tests-parameters' stamp: 'DamienPollet 8/10/2011 20:01'!
testAnyStar

	self assert: anyStar parse: #('abc') to: #('abc').
	self assert: anyStar parse: #('123') to: #('123').
	self assert: anyStar parse: #('x & ;') to: #('x & ;').
	self assert: anyStar parse: #('') to: #('').
	
	self assert: anyStar parse: #('123' 'abc' 'jk6') to: #('123' 'abc' 'jk6').
	
	self assert: anyStar parse: #() to: #().
! !

!CLIParsingTest methodsFor: 'tests-parameters' stamp: 'DamienPollet 8/10/2011 18:42'!
testBool
	self assert: (CLIParameterParser boolean) fail: #('falsely').
	self
		assert: (CLIParameterParser boolean) star
		parse: #('true' 'false' 'yes' 'no' 'No' 'NO')
		to: #(true false true false false false)! !

!CLIParsingTest methodsFor: 'tests-commands' stamp: 'DamienPollet 8/10/2011 20:02'!
testCommand
	self assert: command parse: #('foo' 'xyz' ).
	self assert: command parse: #('fu' 'xyz' ).
	self assert: command parse: #('f' 'xyz' ).
	
	self assert: command fail: #('notfoo' 'xyz').
	
	self assert: command parse: #('foo' '-s' 'xyz' ).
	self assert: command parse: #('foo' '--long' 'xyz' ).
	self assert: command parse: #('foo' '-b' 'right' 'xyz' ).
	self assert: command parse: #('foo' '--both' 'down' '--long' '-s' 'xyz' ).
! !

!CLIParsingTest methodsFor: 'tests-parameters' stamp: 'DamienPollet 8/10/2011 18:42'!
testNumbers
	| numbers |
	numbers := #('123' '42' '-12' '3.14').
	self assert: (CLIParameterParser integer) star
		parse: numbers to: #(123 42) end: 2.
	self assert: (CLIParameterParser relativeInteger) star
		parse: numbers to: #(123 42 -12) end: 3.
	self assert: (CLIParameterParser number) star
		parse: numbers to: #(123 42 -12 3.14).
! !

!CLIParsingTest methodsFor: 'tests-options' stamp: 'DamienPollet 8/10/2011 20:34'!
testOptionArguments
	| p |
	p := optionShort parameter: any.
	self assert: p parse: #('-s' '42' '51' '1337')
		to: (p capture: '42')
		end: 2.
	
	p := optionShort parameter: anyOf , anyOf.
	self assert: p parse: #('-s' 'up' 'left' '1337')
		to: (CLIOption from: p parameter: #('up' 'left'))
		end: 3.
	! !

!CLIParsingTest methodsFor: 'tests-options' stamp: 'DamienPollet 8/10/2011 20:02'!
testOptionLong
	self assert: optionLong
		parse: #('--long')
		to: (optionLong capture).
	
	self assert: optionLong fail: #('--long-long').! !

!CLIParsingTest methodsFor: 'tests-options' stamp: 'DamienPollet 8/11/2011 01:07'!
testOptionNames
	self assert: optionShort displayName = '-s'.
	self assert: optionLong displayName = '--long'.
	self assert: optionBoth displayName = '-b/--both'.
	
	self assert: optionShort name = #s.
	self assert: optionLong name = #long.
	self assert: optionBoth name = #both! !

!CLIParsingTest methodsFor: 'tests-options' stamp: 'DamienPollet 8/10/2011 20:09'!
testOptionShort
	self assert: optionShort shortForm = '-s'.
	self assert: optionShort longForm = nil.
	
	self assert: optionShort parse: #('-s') to: optionShort capture.
	self assert: optionShort fail: #('--s').
	self assert: optionShort fail: #('-ss').! !

!CLIParsingTest methodsFor: 'tests-parameters' stamp: 'DamienPollet 8/10/2011 20:03'!
testParameterNames
	self assert: any name = 'something'.
	self assert: anyOf name = 'direction'.! !

!CLIParsingTest methodsFor: 'tests-commands' stamp: 'DamienPollet 8/10/2011 20:03'!
testSubcommand
	self assert: subcommand parse: #('bar' 'foo' 'xyz' ).
	self assert: subcommand parse: #('bar' 'fu' 'xyz' ).
	self assert: subcommand parse: #('bar' 'f' 'xyz' ).
	
	self assert: subcommand fail: #('notbar' 'foo' 'xyz').
	
	self assert: subcommand parse: #('bar' 'foo' '-s' 'xyz' ).
	self assert: subcommand parse: #('bar' 'foo' '--long' 'xyz' ).
	self assert: subcommand parse: #('bar' 'foo' '-b' 'right' 'xyz' ).
	self assert: subcommand parse: #('bar' 'foo' '--both' 'down' '--long' '-s' 'xyz' ).
! !

PPSmalltalkGrammarTests subclass: #PPCoralGrammarTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Coral-Tests'!

PPCoralGrammarTest subclass: #PPCoralCompilerTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Coral-Tests'!

!PPCoralCompilerTest methodsFor: 'accessing' stamp: 'StephaneDucasse 12/8/2009 17:55'!
parserClass
	^ PPCoralParser! !

!PPCoralCompilerTest methodsFor: 'running' stamp: 'DamienPollet 12/15/2011 15:54'!
setUp
	Object subclass: #CoralTestFixtureClass! !

!PPCoralCompilerTest methodsFor: 'running' stamp: 'DamienPollet 12/15/2011 16:18'!
tearDown
	self class environment
		at: #CoralTestFixtureClass
		ifPresent: [ :it | it removeFromSystem: false].
	self class environment
		at: #SaBox
		ifPresent: [ :it | it removeFromSystem: false]! !

!PPCoralCompilerTest methodsFor: 'tests' stamp: 'StephaneDucasse 12/8/2009 17:55'!
testABlock
	"self debug: #testABlock"
	
	| res |
	res := PPCoralParser parse: '[ 1 + 2]'.
	self assert: res = #(3).
! !

!PPCoralCompilerTest methodsFor: 'tests' stamp: 'DamienPollet 12/15/2011 16:08'!
testAccessIV
	"self debug: #testAccessIV"

	self shouldnt: [PPCoralParser parse: '[
	Object < #SaBox 
		iv: ''bob'' 
	]'
	] raise: Error.

	self shouldnt: [PPCoralParser parse: '
		SaBox>>initialize
		[
		<category: ''initialize release''>
		<authorInitials: ''him''>
		bob := ''Script test working'']'
	] raise: Error.

	self shouldnt: [PPCoralParser parse: '
		SaBox>> printOn: aStream
	[
		"<category: ''printing''>
		<authorInitials: ''him''>"
		aStream nextPutAll: bob
	]'
	] raise: Error.! !

!PPCoralCompilerTest methodsFor: 'tests' stamp: 'StephaneDucasse 12/8/2009 17:55'!
testAnotherBlock
	"self debug: #testAnotherBlock"
	
	self assert: (PPCoralParser parse: '[Beeper beep] ') = {Beeper}						
	! !

!PPCoralCompilerTest methodsFor: 'tests' stamp: 'sd 11/8/2010 09:53'!
testBangAlone
	"self debug: #testBangAlone"
	
	
	self shouldnt: [(PPCoralParser parse: '#!!/bin/usr/coralNegated')] raise: Error.
	
	self shouldnt: [(PPCoralParser parse: '#!!/bin/usr/coralNegated'     )] raise: Error
		
	! !

!PPCoralCompilerTest methodsFor: 'tests' stamp: 'DamienPollet 12/15/2011 16:05'!
testBangProgram
	"self debug: #testBangProgram"
	
	self assert: 
		(PPCoralParser parse: '#!!/bin/usr/coralNegated 
	CoralTestFixtureClass>>blue 
	    [^ 2]
	
	CoralTestFixtureClass>>red 
	    [^ self blue]
	
	[CoralTestFixtureClass new red = 2]' 
		) = #(blue red true)
	! !

!PPCoralCompilerTest methodsFor: 'tests' stamp: 'TestRunner 12/17/2009 14:43'!
testBashHeader
	"self debug: #testBashHeader"
	
	Smalltalk at: #FooBar put: 666.
	self shouldnt: [PPCoralParser parse: 
		'#!!/bin/sh
		[ Smalltalk at: #FooBar put: 33. ]
		'] raise: Error.
	self assert: (Smalltalk at: #FooBar) =33.
	Smalltalk removeKey: #FooBar! !

!PPCoralCompilerTest methodsFor: 'tests' stamp: 'DamienPollet 12/15/2011 16:04'!
testBlueProgram
	"self debug: #testBlueProgram"
	"Pay attention the test should use a class that is in the image"
	

	self assert: (PPCoralParser parse: 'CoralTestFixtureClass>>blue[^2]' )= #(#blue)
	! !

!PPCoralCompilerTest methodsFor: 'tests' stamp: 'DamienPollet 12/15/2011 16:04'!
testBlueWithSpacesProgram
	"self debug: #testBlueWithSpacesProgram"
	
	self assert: 
		(PPCoralParser parse: '
	CoralTestFixtureClass>>blue 
	    [^ 2]
' 
		) = #(blue) 
	! !

!PPCoralCompilerTest methodsFor: 'tests' stamp: 'DamienPollet 12/15/2011 16:02'!
testDefineAMethod
	"self debug: #testDefineAMethod"
	
	PPCoralParser parse: 'CoralTestFixtureClass >>blue [^ 2]'.
	self assert: (self class environment at: #CoralTestFixtureClass) new blue = 2.
! !

!PPCoralCompilerTest methodsFor: 'tests' stamp: 'DamienPollet 12/15/2011 16:02'!
testDefineAMethodWithExtraDot
	"self debug: #testDefineAMethodWithExtraDot"
	
	PPCoralParser parse: 'CoralTestFixtureClass>>blue [^ 2 . ]'.
	self assert: (self class environment at: #CoralTestFixtureClass) new blue = 2.
! !

!PPCoralCompilerTest methodsFor: 'tests' stamp: 'StephaneDucasse 12/7/2009 17:02'!
testFullProgram
	"self debug: #testFullProgram"

	super testFullProgram ! !

!PPCoralCompilerTest methodsFor: 'tests' stamp: 'TestRunner 12/7/2009 23:27'!
testMethodUnary1
	"self debug: #testMethodUnary1"

	super testMethodUnary1.
	self assert: (result = #coralNegated)
	"
	self assert: result isMethod.
	self assert: result arguments isEmpty.
	self assert: result body temporaries isEmpty.
	self assert: result body statements size = 1.
	self assert: result body statements first isReturn.
	self assert: result body statements first value isMessage.
	self assert: result body statements first value receiver isLiteral.
	self assert: result body statements first value selector = #-.
	self assert: result body statements first value arguments size = 1.
	self assert: result body statements first value arguments first isVariable
	"! !

!PPCoralCompilerTest methodsFor: 'tests' stamp: 'DamienPollet 12/15/2011 16:07'!
testScript
	"self debug: #testScript"
	
	self shouldnt: [PPCoralParser parse: '[
	Object subclass: #SaBox
		instanceVariableNames: ''bob''
		classVariableNames: ''''
		poolDictionaries: ''''
		category: ''SandBox''
	]

	SaBox >> initialize
	[
		<category: ''initialize release''>
		<authorInitials: ''him''>
		bob := ''Script test working''.
	]

	SaBox >> printOn: aStream
	[
		"<category: ''printing''>
		<authorInitials: ''him''>"
		aStream nextPutAll: bob
	]

	SaBox class >> dummy
	[
		<authorInitials: ''him''>
		^3
	]

	[
	SaBox new printString.
	]'] raise: Error.

	self assert: (Smalltalk at: #SaBox ifAbsent:[nil]) notNil.
	self assert: (Smalltalk at: #SaBox ifAbsent:[nil]) dummy = 3! !

!PPCoralCompilerTest methodsFor: 'tests' stamp: 'TestRunner 12/17/2009 14:51'!
testScript1
	"self debug: #testScript1"

	self shouldnt: [PPCoralParser parse: '[
	Object subclass: #SaBox
		instanceVariableNames: ''bob''
		classVariableNames: ''''
		poolDictionaries: ''''
		category: ''SandBox''
	]'
	] raise: Error.

	self shouldnt: [PPCoralParser parse: '
		SaBox>>initialize
		[bob := ''Script test working'']'
	] raise: Error.

	PPCoralParser parse: 'SaBox>>bob
		[^ bob ]'.
	self assert: (Smalltalk at: #SaBox) new bob = 'Script test working'
! !

!PPCoralCompilerTest methodsFor: 'tests' stamp: 'DamienPollet 12/15/2011 16:20'!
testWhiteSpaceAfterClassName
	"self debug: #testWhiteSpaceAfterClassName"
	self shouldnt: [PPCoralParser parse: '
		CoralTestFixtureClass >> printOn: aStream
	[
		"<category: ''printing''>
		<authorInitials: ''him''>"
		aStream nextPutAll: ''bob''
	]'
	] raise: Error.! !

!PPCoralGrammarTest methodsFor: 'accessing' stamp: 'StephaneDucasse 12/8/2009 17:56'!
parserClass
	^ PPCoralGrammar! !

!PPCoralGrammarTest methodsFor: 'tests' stamp: 'StephaneDucasse 12/7/2009 15:00'!
testBang
	"self debug: #testBang"

	self 
		parse: '#!!/usr/bin/work '
		rule: #program.
		
	self 
		parse: '#!!/usr/bin/work   '
		rule: #program.
		
		
	! !

!PPCoralGrammarTest methodsFor: 'tests' stamp: 'DamienPollet 12/15/2011 16:12'!
testBangFullProgram
	"self debug: #testBangFullProgram"

	self 
		parse: '#!!/bin/usr/
		[Beeper beep]
		
				CoralTestFixtureClass>> foo 
					[  1 + 2]
				
				CoralTestFixtureClass>> foo2 
					[ ^ 1 + 2]
				
				[Beeper beep]'
		rule: #program
		
	! !

!PPCoralGrammarTest methodsFor: 'tests' stamp: 'TestRunner 12/7/2009 15:00'!
testBangNoSpace
	"self debug: #testBangNoSpace"

	self 
		parse: '#!!/usr/bin/work'
		rule: #program
	! !

!PPCoralGrammarTest methodsFor: 'tests' stamp: 'sd 10/3/2009 13:27'!
testBlock
	"self debug: #testBlock"

	self 
		parse: ' [Beeper beep]'
		rule: #block
		
	! !

!PPCoralGrammarTest methodsFor: 'tests' stamp: 'DamienPollet 3/1/2012 17:02'!
testClass

	self 
		parse: 'Class named: #Foo
					superclass: #Object
					instanceVariables: #(a b c)
					category: ''SandBox'''
		rule: #class
		
	! !

!PPCoralGrammarTest methodsFor: 'tests' stamp: 'DamienPollet 12/15/2011 16:12'!
testFullProgram
	"self debug: #testFullProgram"

	self 
		parse: ' [Beeper beep]
		
				CoralTestFixtureClass>> foo 
					[  1 + 2]
				
				CoralTestFixtureClass>> foo2 
					[ ^ 1 + 2]
				
				[Beeper beep]'
		rule: #program
		
	! !

!PPCoralGrammarTest methodsFor: 'tests' stamp: 'DamienPollet 12/15/2011 16:12'!
testMethod
	"self debug: #testMethod"

	self 
		parse: 'CoralTestFixtureClass>>blue [^ 2]'
		rule: #program
		
	! !

!PPCoralGrammarTest methodsFor: 'tests' stamp: 'DamienPollet 12/15/2011 16:12'!
testMethodBinary1
	"self debug: #testMethodBinary1"

	self 
		parse: 'CoralTestFixtureClass>>+ arg [^ self + arg]'
		rule: #method
		
	! !

!PPCoralGrammarTest methodsFor: 'tests' stamp: 'DamienPollet 12/15/2011 16:12'!
testMethodBinary2
	"self debug: #testMethodBinary2"

	self 
		parse: '     CoralTestFixtureClass    >>   + arg [^ self + arg ]'
		rule: #method
		
	! !

!PPCoralGrammarTest methodsFor: 'tests' stamp: 'DamienPollet 12/15/2011 16:12'!
testMethodBinary3
	"self debug: #testMethodBinary3"

	self 
		parse: '     CoralTestFixtureClass    >>   + arg 
							[^ self + arg ]   '
		rule: #method
		
	! !

!PPCoralGrammarTest methodsFor: 'tests' stamp: 'DamienPollet 12/15/2011 16:12'!
testMethodBinary4
	"self debug: #testMethodBinary4"

	self 
		parse:  '     CoralTestFixtureClass  class  >>   + arg 
							[^ self + arg ]   '
		rule: #method
		
	! !

!PPCoralGrammarTest methodsFor: 'tests' stamp: 'DamienPollet 12/15/2011 16:12'!
testMethodKeyword1
	"self debug: #testMethodKeyword1"

	self 
		parse: 'CoralTestFixtureClass>>coralSetX: x y:y
					 [^ self class new setX: x ; setY: y ]'
		rule: #method
		
	! !

!PPCoralGrammarTest methodsFor: 'tests' stamp: 'DamienPollet 12/15/2011 16:12'!
testMethodKeyword2
	"self debug: #testMethodKeyword2"

	self 
		parse: 'CoralTestFixtureClass >>  coralSetX: x y:y
					 [^ self class new setX: x ; setY: y ] '
		rule: #method
		
	! !

!PPCoralGrammarTest methodsFor: 'tests' stamp: 'DamienPollet 12/15/2011 16:13'!
testMethodKeyword3
	"self debug: #testMethodKeyword3"

	self 
		parse: '   CoralTestFixtureClass >>  coralSetX: x y:        
		   y
					 [^ self class new setX: x ; setY: y ] '
		rule: #method
		
	! !

!PPCoralGrammarTest methodsFor: 'tests' stamp: 'DamienPollet 12/15/2011 16:13'!
testMethodKeyword4
	"self debug: #testMethodKeyword4"

	self 
		parse: '   CoralTestFixtureClass class >>  coralNewX: x y:        
		   y
					 [^ self  new setX: x ; setY: y ] '
		rule: #method
		
	! !

!PPCoralGrammarTest methodsFor: 'tests' stamp: 'DamienPollet 12/15/2011 16:14'!
testMethodUnary1
	"self debug: #testMethodUnary1"

	self 
		parse: 'CoralTestFixtureClass>>coralNegated[^0-self]'
		rule: #method
		
	! !

!PPCoralGrammarTest methodsFor: 'tests' stamp: 'DamienPollet 12/15/2011 16:14'!
testMethodUnary2
	"self debug: #testMethodUnary2"

	self 
		parse: '   CoralTestFixtureClass  >>  coralNegated   [ ^ 0 - self ]  '
		rule: #method
		
	! !

!PPCoralGrammarTest methodsFor: 'tests' stamp: 'DamienPollet 12/15/2011 16:14'!
testMethodUnary3
	"self debug: #testMethod3"

	"for now let us test the following"
	self 
		parse: '   CoralTestFixtureClass >> coralNegated [^ 0 - self]     '
		rule: #method
	! !

!PPCoralGrammarTest methodsFor: 'tests' stamp: 'DamienPollet 12/15/2011 16:14'!
testMethodUnaryClass4
	"self debug: #testMethodUnaryClass4"

	"for now let us test the following"
	self 
		parse: '   CoralTestFixtureClass class >> coralNegated [^ 0 - self]     '
		rule: #program
	! !

!PPCoralGrammarTest methodsFor: 'tests' stamp: 'sd 10/3/2009 13:25'!
testProgram
	"self debug: #testProgram"

	self 
		parse: ' [Beeper beep]'
		rule: #program
		
	! !

!PPCoralGrammarTest methodsFor: 'tests' stamp: 'sd 10/3/2009 13:26'!
testProgramAsASingleBlock
	"self debug: #testProgram"

	self 
		parse: ' [Beeper beep]'
		rule: #program
		
	! !

TestCase subclass: #CoralClassTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Coral-Tests'!

!CoralClassTest methodsFor: 'setup' stamp: 'StephaneDucasse 12/8/2009 17:54'!
setUp

	" does not work ;(
	
	Smalltalk at: #ColorPoint ifPresent: [:each | each removeFromSystem ]
	
	"! !

!CoralClassTest methodsFor: 'tests' stamp: 'DamienPollet 12/15/2011 14:03'!
testClassDefWithOneIV
	"self debug: #testClassDefWithOneIV"
	
	| coloredPointClass |
	coloredPointClass := Point < #ColoredPoint 
							iv: 'color'.
	self assert: coloredPointClass superclass = Point.
	self deny: coloredPointClass instVarNames isEmpty.
	self assert: coloredPointClass instVarNames = #('color')! !

!CoralClassTest methodsFor: 'tests' stamp: 'StephaneDucasse 9/5/2009 19:55'!
testClassDefWithOneSharedIV
	"self debug: #testClassDefWithOneSharedIV"
	
	| coloredPointClass |
	coloredPointClass := Point < #ColoredPoint 
							shared: 'DefaultColor'.
	self assert: coloredPointClass superclass = Point.
	self assert: coloredPointClass instVarNames isEmpty.
	self assert: (coloredPointClass classVarNames  includes: 'DefaultColor')! !

!CoralClassTest methodsFor: 'tests' stamp: 'StephaneDucasse 9/5/2009 19:50'!
testClassDefWithSeveralIV
	"self debug: #testClassDefWithSeveralIV"
	
	| coloredPointClass |
	coloredPointClass := Point < #ColoredPoint 
							iv: 'color z'.
	self assert: coloredPointClass superclass = Point.
	self deny: coloredPointClass instVarNames isEmpty.
	self assert: (coloredPointClass instVarNames includes: 'color').
	self assert: (coloredPointClass instVarNames includes: 'z').! !

!CoralClassTest methodsFor: 'tests' stamp: 'StephaneDucasse 9/5/2009 19:50'!
testClassDefWithSeveralIVWithSeparateDef
	"self debug: #testClassDefWithSeveralIVWithSeparateDef"
	
	| coloredPointClass |
	coloredPointClass := Point < #ColoredPoint 
							iv: 'color';
							iv: 'z'.
	self assert: coloredPointClass superclass = Point.
	self deny: coloredPointClass instVarNames isEmpty.
	self assert: (coloredPointClass instVarNames includes: 'color').
	self assert: (coloredPointClass instVarNames includes: 'z').! !

!CoralClassTest methodsFor: 'tests-arguments' stamp: 'AdrienBarreau 10/13/2010 13:20'!
testExtractAllKinds
	| args extract keys |
	
	args := #('ArgWithoutMinus1' '-ArgWithMinus1' 'ArgWithoutMinus2' 'ArgWithoutMinus3' '-ArgWithMinus2').
	extract := SmalltalkImage current extractMinusParametersFrom: args.
	keys := extract keys sort.
	
	self assert: extract isDictionary.
	self assert: extract size = 3.
	self assert: ((keys at:1) = #*).
	self assert: ((keys at:2) = #ArgWithMinus1).
	self assert: ((keys at:3) = #ArgWithMinus2).
	self assert: ((extract at:#*) = (Array with: 'ArgWithoutMinus1')).
	self assert: ((extract at:#ArgWithMinus1) = #('ArgWithoutMinus2' 'ArgWithoutMinus3')).
	self assert: ((extract at: #ArgWithMinus2) isEmpty)
	! !

!CoralClassTest methodsFor: 'tests-arguments' stamp: 'AdrienBarreau 10/13/2010 13:09'!
testExtractEmpty
	| args extract |
	
	args := #().
	extract := SmalltalkImage current extractMinusParametersFrom: args.
	
	self assert: extract class = Dictionary.
	self assert: extract isEmpty.
	! !

!CoralClassTest methodsFor: 'tests-arguments' stamp: 'AdrienBarreau 10/13/2010 13:08'!
testExtractNil
	| args extract |
	
	args := nil.
	extract := SmalltalkImage current extractMinusParametersFrom: args.
	
	self assert: extract class = Dictionary.
	self assert: extract isEmpty.
	! !

!CoralClassTest methodsFor: 'tests-arguments' stamp: 'AdrienBarreau 10/13/2010 13:18'!
testExtractOneArgNoMinus
	| args extract |
	
	args := #('ArgNoMinus').
	extract := SmalltalkImage current extractMinusParametersFrom: args.
	
	self assert: extract isDictionary.
	self assert: extract size = 1.
	self assert: ((extract keys at:1) = #*).
	self assert: ((extract at:#*) = args)
	! !

!CoralClassTest methodsFor: 'tests-arguments' stamp: 'AdrienBarreau 10/13/2010 13:20'!
testExtractOneArgWithMinus
	| args extract |
	
	args := #('-ArgWithMinus').
	extract := SmalltalkImage current extractMinusParametersFrom: args.
	
	self assert: extract isDictionary.
	self assert: extract size = 1.
	self assert: ((extract keys at:1) = #ArgWithMinus).
	self assert: ((extract at:#ArgWithMinus) isEmpty)
	! !

!CoralClassTest methodsFor: 'tests-arguments' stamp: 'AdrienBarreau 10/13/2010 13:25'!
testExtractOneArgWithMinusThenArgsWithout
	| args extract |
	
	args := #('-ArgWithMinus' 'ArgWithoutMinus1' 'ArgWithoutMinus2' ).
	extract := SmalltalkImage current extractMinusParametersFrom: args.
	
	self assert: extract isDictionary.
	self assert: extract size = 1.
	self assert: ((extract keys at:1) = #ArgWithMinus).
	self assert: ((extract at:#ArgWithMinus) = #('ArgWithoutMinus1' 'ArgWithoutMinus2' ))
	! !

!CoralClassTest methodsFor: 'tests-arguments' stamp: 'AdrienBarreau 10/13/2010 15:26'!
testExtractTwoArgsWithAndWithoutMinus
	| args extract keys |
	
	args := #('ArgWithoutMinus' '-ArgWithMinus').
	extract := SmalltalkImage current extractMinusParametersFrom: args.
	keys := extract keys sort.
	
	self assert: extract isDictionary.
	self assert: extract size = 2.
	self assert: ((keys at:1) = #*).
	self assert: ((keys at:2) = #ArgWithMinus).
	self assert: ((extract at:#*) = (Array with: 'ArgWithoutMinus')).
	self assert: ((extract at:#ArgWithMinus) isEmpty)
	! !

!CoralClassTest methodsFor: 'tests' stamp: 'StephaneDucasse 9/5/2009 19:42'!
testSimpleClassDef
	"self debug: #testSimpleClassDef"
	
	| coloredPointClass |
	coloredPointClass := Point < #ColoredPoint.
	self assert: coloredPointClass superclass = Point.
	self assert: coloredPointClass instVarNames isEmpty! !

!CoralClassTest methodsFor: 'tests' stamp: 'DamienPollet 12/15/2011 15:38'!
testSimpleClassDefWithPackage
	"self debug: #testSimpleClassDefWithPackage"
	
	| coloredPointClass |
	coloredPointClass := Point < #ColoredPoint
							category: #Box.
	self assert: coloredPointClass superclass = Point.
	self assert: coloredPointClass package name = #Box.
	self assert: coloredPointClass category = #Box.
	! !
